# item_tracking

## Overview
This is a tracking package for items, which are define with a complete structure.
Item can be define either by PointCloud as define in ROS, or with components.
These components have 3D pose, orientation and size.
The tracking matches check each iteration the evolution of tracked items depending on how the parameters are set.

## Examples
Examples of how this package can be used are in the directory examples.

## Installation
`pip install item_tracking` should work for most users.
